@@ -2,9 +2,9 @@
  *
  * SEND_NSCA.C - NSCA Client
  * License: GPL v2
- * Copyright (c) 2000-2006 Ethan Galstad (nagios@nagios.org)
+ * Copyright (c) 2000-2007 Ethan Galstad (nagios@nagios.org)
  *
- * Last Modified: 04-06-2006
+ * Last Modified: 07-03-2007
  *
  * Command line: SEND_NSCA <host_address> [-p port] [-to to_sec] [-c config_file]
  *
@@ -81,7 +81,7 @@ int main(int argc, char **argv){
 			printf("Incorrect command line arguments supplied\n");
 		printf("\n");
 		printf("NSCA Client %s\n",PROGRAM_VERSION);
-		printf("Copyright (c) 2000-2006 Ethan Galstad (www.nagios.org)\n");
+		printf("Copyright (c) 2000-2007 Ethan Galstad (www.nagios.org)\n");
 		printf("Last Modified: %s\n",MODIFICATION_DATE);
 		printf("License: GPL v2\n");
 		printf("Encryption Routines: ");
@@ -421,7 +421,7 @@ int process_arguments(int argc, char **argv){
 		/* config file */
 		else if(!strcmp(argv[x-1],"-c")){
 			if(x<argc){
-				snprintf(config_file,sizeof(config_file),argv[x]);
+				snprintf(config_file,sizeof(config_file),"%s",argv[x]);
 				config_file[sizeof(config_file)-1]='\x0';
 				x++;
 			        }
@@ -432,7 +432,7 @@ int process_arguments(int argc, char **argv){
 		/* delimiter to use when parsing input */
 		else if(!strcmp(argv[x-1],"-d")){
 			if(x<argc){
-				snprintf(delimiter,sizeof(delimiter),argv[x]);
+				snprintf(delimiter,sizeof(delimiter),"%s",argv[x]);
 				delimiter[sizeof(delimiter)-1]='\x0';
 				x++;
 			        }
